#
# spec file for package emacs-compat
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Björn Bidar
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _name    compat

Name:           emacs-%{_name}
Version:        29.1.4.5
Release:        1.1
Summary:        COMPATibility Library for Emacs Lisp
License:        GPL-3.0-or-later
Group:          Productivity/Text/Editors
URL:            https://github.com/emacs-compat/compat
Source0:        %{_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  emacs-devel
BuildRequires:  emacs-nox
BuildRequires:  info
BuildRequires:  make
BuildRequires:  makeinfo
Requires:       emacs
Supplements:    emacs
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
# PATCH-FEATURE-UPSTREAM install targets PR 30
Patch1:         0001-Add-install-target.patch

%description
compat.el, the forwards-compatibility library for (GNU) Emacs Lisp, versions 24.4 and newer. The intended audience are package developers that are interested in using newer developments, without having to break compatibility.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%make_build

%install
%make_install

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{_name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{_name}.info.gz

%files
%doc README.md
%license COPYING
%{_emacs_sitelispdir}/%{_name}*.el*
%{_infodir}/%{_name}*

%changelog
* Mon Mar 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 29.1.4.5:
  * Update NEWS.org
  * compat-tests: Fix compat-thing-at-mouse test
  * Use https links everywhere
  * compat.texi: Use @dfn{Extended Definitions}
  * NEWS: Mention addition of compat.el to Emacs
  * compat.texi: Update manual after the inclusion of compat.el in Emacs
  * compat-tests: Fix commentary linter warnings
  * compat-tests: Use should-equal
  * compat--maybe-require: Rename macro to reduce churn
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Depend on emacs-devel to make sure Emacs packaging macros are installed when not building with emacs-eln
* Wed Jan 31 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 29.1.4.4:
  * The maintainer field accepts only a single mail address
  * fix(compat.el): Package-Requires "seq" = 2.3 -> 2.23 (#31)
  * compat.texi: Fix typos
* Wed Sep 27 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for OpenSuSE
- Include patch to add install targets to upstream makefiles
- Compat 29.1.4.2
  * compat-28: Improve =make-separator-line= visuals on graphic displays
  * compat-28: Add =native-comp-available-p=, which always returns nil
  * compat-29: Add variable =lisp-directory=
